@@ -13,7 +13,7 @@
 
 # Include /usr/bin in path to find on_ac_power if /usr/ is on the root
 # partition.
-PATH=/sbin:/bin:/usr/bin
+PATH=/usr/bin:/sbin:/bin
 FSCK_LOGFILE=/var/log/fsck/checkroot
 [ "$FSCKFIX" ] || FSCKFIX=no
 [ "$SULOGIN" ] || SULOGIN=no
@@ -22,6 +22,12 @@ FSCK_LOGFILE=/var/log/fsck/checkroot
 . /lib/lsb/init-functions
 . /lib/init/mount-functions.sh
 
+if command -v setterm >/dev/null 2>&1; then
+	setterm=setterm
+else
+	setterm='true -- '
+fi
+
 _want_force_fsck () {
 	case "$(findmnt -n -o FSTYPE /)" in
 	# Only ext* file systems support `-f' option to fsck. See #686895
@@ -94,7 +100,7 @@ do_start () {
 	#
 	# Does the root device in /etc/fstab match with the actual device ?
 	# If not we try to use the /dev/root alias device, and if that
-	# fails we create a temporary node in /run.
+	# fails we create a temporary node in /dev.
 	#
 	# Do this only on Linux. Neither kFreeBSD nor Hurd have
 	# /dev/root and the device ids used here are specific to
@@ -111,11 +117,11 @@ do_start () {
 				rootdev=/dev/root
 			else
 				if \
-					rm -f /run/rootdev \
-					&& mknod -m 600 /run/rootdev b ${rdev%:*} ${rdev#*:} \
-					&& [ -e /run/rootdev ]
+					rm -f /dev/rootdev \
+					&& mknod -m 600 /dev/rootdev b ${rdev%:*} ${rdev#*:} \
+					&& [ -b /dev/rootdev ]
 				then
-					rootdev=/run/rootdev
+					rootdev=/dev/rootdev
 				else
 					rootfatal=yes
 				fi
@@ -130,7 +136,7 @@ do_start () {
 	then
 		log_failure_msg "The device node $rootdev for the root filesystem is missing or incorrect 
 or there is no entry for the root filesystem listed in /etc/fstab. 
-The system is also unable to create a temporary node in /run. 
+The system is also unable to create a temporary node in /dev. 
 This means you have to fix the problem manually."
 		log_warning_msg "A maintenance shell will now be started. 
 CONTROL-D will terminate this shell and restart the system."
@@ -168,6 +174,13 @@ Will restart in 5 seconds."
 	if [ -e /run/initramfs/fsck-root ]
 	then
 		rootcheck=no
+		# logsave_best_effort but do not display again
+		if [ -x /sbin/logsave ] && [ -e "${FSCK_LOGFILE}" ]; then
+			logsave -s "${FSCK_LOGFILE}" >/dev/null \
+			    cat /run/initramfs/fsck.log
+		else
+			log_failure_msg "Cannot persist initramfs fsck.log"
+		fi
 	fi
 
 	if is_fastboot_active
@@ -239,8 +252,10 @@ Will restart in 5 seconds."
 		if [ "$VERBOSE" = no ]
 		then
 			log_action_begin_msg "Checking root file system"
-			logsave_best_effort fsck $spinner $force $fix -t $roottype $rootdev
+			$setterm --msg off
+			logsave_best_effort fsck $spinner $force $fix -T -t $roottype $rootdev
 			FSCKCODE=$?
+			$setterm --msg on
 			if [ "$FSCKCODE" = 0 ]
 			then
 				log_action_end_msg 0
@@ -249,7 +264,7 @@ Will restart in 5 seconds."
 			fi
 		else
 			log_daemon_msg "Will now check root file system"
-			logsave_best_effort fsck $spinner $force $fix -V -t $roottype $rootdev
+			logsave_best_effort fsck $spinner $force $fix -T -V -t $roottype $rootdev
 			FSCKCODE=$?
 			log_end_msg $FSCKCODE
 		fi
@@ -321,9 +336,9 @@ but requested that the system be restarted."
 	fi
 
 	#
-	# Remove /run/rootdev if we created it.
+	# Remove /dev/rootdev if we created it.
 	#
-	rm -f /run/rootdev
+	rm -f /dev/rootdev
 
 	# Update mount options for mounts created in early boot
 	# S01mountkernfs.sh
